"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MaterialTabBar = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _helpers = require("./helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Default android control.
 *
 * Example usage:
 *
 * ```tsx
 * import {
 *  Segmented,
 *  MaterialTabBar
 * } from 'react-native-collapsible-segmented-view
 *
 * ...
 *
 * <Segmented.View
 *  control={(props) => <MaterialTabBar {...props} indicatorStyle='red' />}
 * >
 *  ...
 * ```
 */
const MaterialTabBar = ({
  setIndex,
  labels,
  floatIndex,
  containerStyle,
  tabStyle,
  indicatorStyle,
  pressColor = 'DDDDDD',
  pressOpacity = _helpers.IS_IOS ? 0.2 : 1,
  labelStyle,
  inactiveOpacity = 0.4 // ...rest

}) => {
  const windowWidth = (0, _reactNative.useWindowDimensions)().width;

  const onTabPress = _react.default.useCallback(nextIndex => {
    setIndex(nextIndex);
  }, [setIndex]);

  const [translateX, setTraslateX] = _react.default.useState(floatIndex.interpolate({
    inputRange: labels.map((_, i) => i),
    outputRange: labels.map((_, i) => windowWidth / labels.length * i)
  }));

  _react.default.useEffect(() => {
    setTraslateX(floatIndex.interpolate({
      inputRange: labels.map((_, i) => i),
      outputRange: labels.map((_, i) => windowWidth / labels.length * i)
    }));
  }, [floatIndex, labels, windowWidth]);

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, containerStyle]
  }, labels.map((label, index) => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
      key: label,
      onPress: () => onTabPress(index),
      android_ripple: {
        borderless: true,
        color: pressColor
      },
      style: ({
        pressed
      }) => [{
        opacity: pressed ? pressOpacity : 1
      }, styles.tab, tabStyle]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.Text, {
      style: [styles.label, {
        opacity: floatIndex.interpolate({
          inputRange: labels.map((_, i) => i),
          outputRange: labels.map((_, i) => i === index ? 1 : inactiveOpacity)
        })
      }, labelStyle]
    }, label));
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.indicator, indicatorStyle, {
      transform: [{
        translateX
      }],
      width: windowWidth / labels.length
    }]
  }));
};

exports.MaterialTabBar = MaterialTabBar;

const styles = _reactNative.StyleSheet.create({
  container: {
    flexDirection: 'row'
  },
  tab: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    paddingHorizontal: 10,
    height: 48
  },
  label: {
    margin: 4,
    color: 'black'
  },
  indicator: {
    position: 'absolute',
    bottom: 0,
    height: 2,
    backgroundColor: '#2196f3'
  }
});
//# sourceMappingURL=MaterialTabBar.js.map