"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Segment = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _SegmentContext = require("./SegmentContext");

var _SegmentedViewContext = require("./SegmentedViewContext");

var _helpers = require("./helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Wrap your screens with `Segmented.Segment`. Basic usage looks like this:
 *
 * ```tsx
 * <Segmented.View ...>
 *  <Segmented.Segment label="A" component={ScreenA} />
 *  <Segmented.Segment label="B" component={ScreenB} />
 *  <Segmented.Segment label="C" component={ScreenC} />
 * </Segmented.Container>
 * ```
 */
const Segment = ({
  component: Component
}) => {
  const {
    opacity,
    zIndex,
    index: segmentIndex
  } = (0, _SegmentContext.useSegmentContext)();
  const {
    lazy,
    setIndex,
    initialIndex,
    index,
    prevIndex
  } = (0, _SegmentedViewContext.useSegmentedViewContext)();

  const trackMount = _react.default.useRef(lazy ? initialIndex === segmentIndex : true);

  const [wrapperOpacity] = _react.default.useState(new _reactNative.Animated.Value(trackMount.current ? 1 : 0));

  const [mount, setMount] = _react.default.useState(trackMount.current);

  _react.default.useEffect(() => {
    let listener = '';

    if (lazy) {
      listener = index.addListener(({
        value
      }) => {
        if (!trackMount.current && value === segmentIndex) {
          setMount(true);
        }
      });
    }

    return () => {
      if (lazy) {
        index.removeListener(listener);
      }
    };
  }, [index, lazy, segmentIndex]);

  _react.default.useEffect(() => {
    if (mount && !trackMount.current) {
      trackMount.current = mount;
      setIndex(segmentIndex, prevIndex.current, true);
      (0, _helpers.spring)(wrapperOpacity, 1).start();
    }
  }, [mount, prevIndex, segmentIndex, setIndex, wrapperOpacity]);

  return /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.scene, {
      opacity,
      zIndex
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.wrapper, {
      opacity: wrapperOpacity
    }]
  }, mount && /*#__PURE__*/_react.default.createElement(Component, null)));
};

exports.Segment = Segment;

const styles = _reactNative.StyleSheet.create({
  scene: { ..._reactNative.StyleSheet.absoluteFillObject,
    zIndex: -1,
    opacity: 0
  },
  wrapper: {
    flex: 1
  }
});
//# sourceMappingURL=Segment.js.map